#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#

%define	enable_autotools 1

%if 0%{?fedora}
%global		with_python3 1
%global		__python_bin %{__python3}
%global		__python_sitelib %{python3_sitelib}
%else
%global		__python_bin %{__python2}
%global		__python_sitelib %{python2_sitelib}
%endif

%global		package_version 4.1.8
%global		package_name ovirt-log-collector

Summary:	Log Collector for oVirt Engine
Name:		%{package_name}
Version:	4.1.8
Release:	1%{?release_suffix}%{?dist}
License:	ASL 2.0
URL:		http://www.ovirt.org
Source0:	http://resources.ovirt.org/pub/src/%{package_name}/%{package_name}-%{package_version}.tar.gz

BuildArch:	noarch

Requires:	logrotate
Requires:	openssh-clients
Requires:	sos >= 3.3

Requires:	ovirt-engine-lib

BuildRequires:	gettext

%if 0%{?with_python3}
Requires:	python3
Requires:	python3-dateutil
Requires:	python3-lxml
Requires:	python3-ovirt-engine-sdk4 >= 4.1.2
BuildRequires:	python3-devel
%else
Requires:	python
Requires:	python-dateutil
Requires:	python-lxml
Requires:	python-ovirt-engine-sdk4 >= 4.1.2
BuildRequires:	python2-devel
%endif

%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gettext-devel
%endif

%description
Log Collector tool for oVirt Engine

%package analyzer
Summary:	Log Collector for oVirt Engine - Analysis tools
Requires:	rubygem-asciidoctor
Requires:	libxml2
Requires:	postgresql-server
Requires:	coreutils
License:	ASL 2.0 and GPLv2+

%description analyzer
This package contains tools to help analyze oVirt Log Collector archives

%prep
%setup -q -n %{package_name}-%{package_version}

%build
%if 0%{?enable_autotools}
autoreconf -ivf
%endif
%configure \
	--docdir="%{_docdir}/%{package_name}-%{version}" \
	--disable-python-syntax-check \
	PYTHON="%{__python_bin}"
make %{?_smp_mflags}

%check
make check

%install
make %{?_smp_mflags} install DESTDIR="%{buildroot}"

%files
%doc AUTHORS
%license COPYING
%dir %{_localstatedir}/log/ovirt-engine/%{package_name}
%dir %{_sysconfdir}/ovirt-engine/logcollector.conf.d
%config(noreplace) %{_sysconfdir}/ovirt-engine/logcollector.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{package_name}
%{__python_sitelib}/ovirt_log_collector/
%{_bindir}/ovirt-log-collector
%{_mandir}/man8/*

%files analyzer
%doc AUTHORS
%doc COPYING
%doc COPYING-GPL
%{_bindir}/ovirt-log-collector-analyzer
%dir %{_datadir}/%{name}/analyzer
%{_datadir}/%{name}/analyzer/

%changelog
* Tue Feb 20 2018 Sandro Bonazzola <sbonazzo@redhat.com> - 4.1.8-1
- Rebase on upstream 4.1.8

* Fri Nov 24 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.1.7-1
- Rebase on upstream 4.1.7

* Tue Sep 05 2017 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.1.6-1
- Rebase on upstream 4.1.6

* Thu Aug 10 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.1.5-1
- Rebuild including correct sources

* Wed Aug 09 2017 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.1.5-0
- Rebase on upstream 4.1.5

* Mon Jul 17 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.1.4-2
- Fixed rpmdiff issues

* Wed Jul 12 2017 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.1.4-1
- Rebase on upstream 4.1.4

* Thu Jun  8 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.1.3-1
- Rebase on upstream 4.1.3
- Resolves: BZ#1447790

* Fri May 26 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.1.2-1
- Rebase on upstream 4.1.2
- Resolves: BZ#1455771
- Resolves: BZ#1455781

* Tue Apr 04 2017 Lev Veyde <lveyde@redhat.com> - 4.1.1-1
- Rebase on upstream 4.1.1
- Resolves: BZ#1444461

* Thu Jan 19 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.1.0-1
- Rebase on upstream 4.1.0
- Resolves: BZ#1381265

* Tue Aug 30 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.0.1-1
- Rebase on upstream 4.0.1
- Resolves: BZ#1371405
- Resolves: BZ#1330759
- Resolves oVirt BZ#1363684
- Resolves oVirt BZ#1355966

* Tue May 31 2016 Rafael Martins <rmartins@redhat.com> - 4.0.0-1
- 4.0.0-1

* Wed May 18 2016 Rafael Martins <rmartins@redhat.com> - 4.0.0-0.2.master.git3218ba1
- 4.0.0.0.2.master.git3218ba1

* Mon Mar 14 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.0.0-0.1.master.git668ba27
- 4.0.0-0.1.master.git668ba27

* Wed Aug  5 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.0.0-0.0.master.gitcfad1e5
- 4.0.0-0.0.master.gitcfad1e5
- Resolves: BZ#1210800
